Contributing and developing — Cabby 0.1.5 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Cabby 0.1.5 documentation »

# Contributing and developing

## Reporting issues

Cabby uses Github’s issue tracker. See the Cabby project page on Github.

## Obtaining the source code

The Cabby source code can be found on Github. See the Cabby project page on Github.

## Layout

The Cabby repository has the following layout:

- `docs/` - used to build the documentation;
- `cabby/` - source code;
- `tests/` - tests.

## Compiling from source

After cloning the Github repo, just run:

    $ python setup.py install

## Running the tests

Almost all Cabby code is covered by the unit tests. Cabby uses py.test and tox for running tests. Type `tox -r` or `py.test` to run the unit tests.

## Generating the documentation

The documentation is written in ReStructuredText (reST) format and processed using Sphinx. To build HTML documentation, go to `docs` and type `make html`.

Next steps

Continue to License.

### Navigation

- index
- modules |
- next |
- previous |
- Cabby 0.1.5 documentation »